@@ -2,6 +2,7 @@ import sys
 import subprocess  # nosec
 from pathlib import Path
 
+from flaky import flaky
 from dash.testing.composite import DashComposite
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.common.exceptions import (
@@ -10,6 +11,7 @@ from selenium.common.exceptions import (
 )
 
 
+@flaky(max_runs=5)
 def test_full_example(
     testdata_folder: Path, dash_duo: DashComposite, tmp_path: Path
 ) -> None:
@@ -85,5 +87,4 @@ def test_full_example(
             )
         ]
 
-        if logs != []:
-            raise AssertionError(page, logs)
+        assert logs == [], f"Console log not empty ({logs}) on page {page}"
