@@ -1,5 +1,8 @@
 from .ensemble_model import EnsembleModel
 from .ensemble_set_model import EnsembleSetModel
 from .surface_leaflet_model import SurfaceLeafletModel
+from .observation_model import ObservationModel
+from .parameter_model import ParametersModel
 from .surface_set_model import SurfaceSetModel
 from .well_set_model import WellSetModel
+from .inplace_volumes_model import InplaceVolumesModel
