@@ -1,7 +1,5 @@
 from typing import Callable
-
 import dash_html_components as html
-import dash_core_components as dcc
 from webviz_config import WebvizConfigTheme
 
 import webviz_core_components as wcc
@@ -14,33 +12,36 @@ def main_view(
     get_uuid: Callable,
     vectormodel: SimulationTimeSeriesModel,
     parametermodel: ParametersModel,
+    parameterfilter_layout: html.Div,
     theme: WebvizConfigTheme,
-) -> dcc.Tabs:
+) -> wcc.Tabs:
     tabs = [
         wcc.Tab(
             label="Parameter distributions",
+            value="tab-1",
             children=parameter_qc_view(
                 get_uuid=get_uuid, parametermodel=parametermodel
             ),
         )
     ]
+
     if vectormodel is not None:
         tabs.append(
             wcc.Tab(
                 label="Parameters impact on simulation profiles",
+                value="tab-2",
                 children=parameter_response_view(
                     get_uuid=get_uuid,
                     parametermodel=parametermodel,
+                    parameterfilter_layout=parameterfilter_layout,
                     vectormodel=vectormodel,
                     theme=theme,
                 ),
             )
         )
 
-    return html.Div(
-        id=get_uuid("layout"),
-        children=wcc.Tabs(
-            style={"width": "100%"},
-            children=tabs,
-        ),
+    return wcc.Tabs(
+        value="tab-1" if vectormodel is None else "tab-2",
+        style={"width": "100%"},
+        children=tabs,
     )
