@@ -1,38 +1,40 @@
-from typing import Tuple, TYPE_CHECKING
+from typing import Tuple, Callable
 
+import pandas as pd
 import dash
 from dash.dependencies import Input, Output, ALL
 import dash_html_components as html
 import plotly.graph_objects as go
 
+from webviz_subsurface._models import SurfaceLeafletModel
 from ..views.property_delta_view import table_view, surface_views
 from ..utils.surface import surface_from_zone_prop
-from ..models.surface_leaflet_model import (
-    SurfaceLeafletModel,
-)
 
-if TYPE_CHECKING:
-    # pylint: disable=cyclic-import
-    from ..property_statistics import PropertyStatistics
+from ..models import PropertyStatisticsModel
 
 
-def property_delta_controller(parent: "PropertyStatistics", app: dash.Dash) -> None:
+def property_delta_controller(
+    get_uuid: Callable,
+    property_model: PropertyStatisticsModel,
+    surface_table: pd.DataFrame,
+    app: dash.Dash,
+) -> None:
     @app.callback(
-        Output(parent.uuid("delta-bar-graph"), "figure"),
-        Output(parent.uuid("delta-table-surface-wrapper"), "children"),
-        Input(parent.uuid("delta-switch-table-surface"), "value"),
-        Input(parent.uuid("delta-sort"), "value"),
-        Input({"id": parent.uuid("ensemble-selector"), "tab": "delta"}, "value"),
-        Input({"id": parent.uuid("delta-ensemble-selector"), "tab": "delta"}, "value"),
+        Output(get_uuid("delta-bar-graph"), "figure"),
+        Output(get_uuid("delta-table-surface-wrapper"), "children"),
+        Input(get_uuid("delta-switch-table-surface"), "value"),
+        Input(get_uuid("delta-sort"), "value"),
+        Input({"id": get_uuid("ensemble-selector"), "tab": "delta"}, "value"),
+        Input({"id": get_uuid("delta-ensemble-selector"), "tab": "delta"}, "value"),
         Input(
-            {"id": parent.uuid("property-selector"), "tab": "delta"},
+            {"id": get_uuid("property-selector"), "tab": "delta"},
             "value",
         ),
         Input(
-            {"id": parent.uuid("filter-selector"), "tab": "delta", "selector": ALL},
+            {"id": get_uuid("filter-selector"), "tab": "delta", "selector": ALL},
             "value",
         ),
-        Input(parent.uuid("delta-bar-graph"), "clickData"),
+        Input(get_uuid("delta-bar-graph"), "clickData"),
     )
     def _update_bars(
         plot_type: str,
@@ -44,7 +46,7 @@ def property_delta_controller(parent: "PropertyStatistics", app: dash.Dash) -> N
         clickdata: dict,
     ) -> Tuple[go.Figure, html.Div]:
         # Make bar chart
-        bars = parent.pmodel.make_delta_bars(
+        bars = property_model.make_delta_bars(
             prop=prop,
             ensemble=ensemble,
             delta_ensemble=delta_ensemble,
@@ -61,14 +63,15 @@ def property_delta_controller(parent: "PropertyStatistics", app: dash.Dash) -> N
             )
             # Make surface div
             wrapper = make_surfaces(
-                parent=parent,
+                get_uuid=get_uuid,
+                surface_table=surface_table,
                 prop=prop,
                 zone=label.split(" | ")[0],
                 ensemble=ensemble,
                 delta_ensemble=delta_ensemble,
             )
         if plot_type == "table":
-            columns, data = parent.pmodel.make_delta_table(
+            columns, data = property_model.make_delta_table(
                 prop=prop,
                 ensemble=ensemble,
                 delta_ensemble=delta_ensemble,
@@ -81,22 +84,32 @@ def property_delta_controller(parent: "PropertyStatistics", app: dash.Dash) -> N
 
 
 def make_surfaces(
-    parent: "PropertyStatistics",
+    surface_table: pd.DataFrame,
     prop: str,
     zone: str,
     ensemble: str,
     delta_ensemble: str,
+    get_uuid: Callable,
     statistic: str = "mean",
 ) -> html.Div:
 
-    sprop = parent.surface_renaming.get(prop, prop)
-    szone = parent.surface_renaming.get(zone, zone)
-    ens_surface = surface_from_zone_prop(
-        parent, zone=szone, prop=sprop, ensemble=ensemble, stype=statistic
-    )
-    delta_ens_surface = surface_from_zone_prop(
-        parent, zone=szone, prop=sprop, ensemble=delta_ensemble, stype=statistic
-    )
+    try:
+        ens_surface = surface_from_zone_prop(
+            surface_table,
+            zone=zone,
+            prop=prop,
+            ensemble=ensemble,
+            stype=statistic,
+        )
+        delta_ens_surface = surface_from_zone_prop(
+            surface_table,
+            zone=zone,
+            prop=prop,
+            ensemble=delta_ensemble,
+            stype=statistic,
+        )
+    except ValueError:
+        return html.Div("No surfaces found")
 
     # Truncating surface values to highest low and lowest high for each map
     min_val = max([ens_surface.values.min(), delta_ens_surface.values.min()])
@@ -116,7 +129,7 @@ def make_surfaces(
         diff_layer=SurfaceLeafletModel(diff_surface, name="diff_surface").layer,
         ensemble=ensemble,
         delta_ensemble=delta_ensemble,
-        parent=parent,
+        get_uuid=get_uuid,
         prop=prop,
         zone=zone,
     )
