@@ -23,6 +23,7 @@ def selections_controllers(
         State(get_uuid("page-selected"), "data"),
         State(get_uuid("tabs"), "value"),
         State(get_uuid("selections"), "data"),
+        State(get_uuid("initial-load-info"), "data"),
         State({"id": get_uuid("selections"), "tab": ALL, "selector": ALL}, "id"),
         State({"id": get_uuid("filters"), "tab": ALL, "selector": ALL}, "id"),
     )
@@ -33,6 +34,7 @@ def selections_controllers(
         selected_page: str,
         selected_tab: str,
         previous_selection: dict,
+        initial_load: dict,
         selector_ids: list,
         filter_ids: list,
     ) -> dict:
@@ -57,7 +59,9 @@ def selections_controllers(
         page_selections.update(Colorscale=colorscale)
         page_selections.update(ctx_clicked=ctx["prop_id"])
 
-        if previous_selection.get(selected_page) is None:
+        # check if a page needs to be updated due to page refresh or
+        # change in selections/filters
+        if initial_load[selected_page]:
             page_selections.update(update=True)
         else:
             equal_list = []
@@ -71,6 +75,17 @@ def selections_controllers(
         previous_selection[selected_page] = page_selections
         return previous_selection
 
+    @app.callback(
+        Output(get_uuid("initial-load-info"), "data"),
+        Input(get_uuid("page-selected"), "data"),
+        State(get_uuid("initial-load-info"), "data"),
+    )
+    def _store_initial_load_info(page_selected: str, initial_load: dict) -> dict:
+        if initial_load is None:
+            initial_load = {}
+        initial_load[page_selected] = page_selected not in initial_load
+        return initial_load
+
     @app.callback(
         Output(
             {"id": get_uuid("selections"), "tab": "voldist", "selector": ALL},
@@ -208,11 +223,8 @@ def selections_controllers(
         Output(
             {"id": get_uuid("filters"), "tab": ALL, "element": "real_text"}, "children"
         ),
-        Input({"id": get_uuid("selections"), "tab": ALL, "selector": ALL}, "value"),
         Input(get_uuid("page-selected"), "data"),
-        Input(
-            {"id": get_uuid("main-voldist"), "element": "plot-table-select"}, "value"
-        ),
+        Input({"id": get_uuid("selections"), "tab": ALL, "selector": ALL}, "value"),
         Input({"id": get_uuid("filters"), "tab": ALL, "component_type": ALL}, "value"),
         State({"id": get_uuid("selections"), "tab": ALL, "selector": ALL}, "id"),
         State(get_uuid("tabs"), "value"),
@@ -223,9 +235,8 @@ def selections_controllers(
         State({"id": get_uuid("filters"), "tab": ALL, "element": "real_text"}, "id"),
     )
     def _update_filter_options(
+        _selected_page: str,
         selectors: list,
-        selected_page: str,
-        plot_table_select: str,
         reals: list,
         selector_ids: list,
         selected_tab: str,
@@ -255,20 +266,8 @@ def selections_controllers(
                 page_selections[x]
                 for x in ["Color by", "Subplots", "X Response", "Y Response"]
             ]
-            table_groups = (
-                page_selections["Group by"]
-                if page_selections["Group by"] is not None
-                else []
-            )
-
-            if selected_page == "1p1t" and not page_selections["sync_table"]:
-                selected_data.extend(table_groups)
-            if (
-                selected_page == "custom"
-                and plot_table_select == "table"
-                and not page_selections["sync_table"]
-            ):
-                selected_data = table_groups
+        if selected_tab == "table" and page_selections["Group by"] is not None:
+            selected_data = page_selections["Group by"]
 
         output = {}
         for selector in ["SOURCE", "ENSEMBLE"]:
@@ -282,6 +281,15 @@ def selections_controllers(
                 multi = values = dash.no_update
             output[selector] = {"multi": multi, "values": values}
 
+        # filter tornado on correct fluid based on volume response chosen
+        output["FLUID_ZONE"] = {}
+        if selected_tab == "tornado" and page_selections["mode"] == "locked":
+            output["FLUID_ZONE"] = {
+                "values": [
+                    "oil" if page_selections["Response right"] == "STOIIP" else "gas"
+                ]
+            }
+
         # realization
         index = [x["tab"] for x in reals_ids].index(selected_tab)
         real_list = [int(real) for real in reals[index]]
@@ -299,20 +307,20 @@ def selections_controllers(
                 id_list=filter_ids,
                 update_info=[
                     {
-                        "new_value": output[item].get("multi", dash.no_update),
-                        "conditions": {"tab": selected_tab, "selector": item},
+                        "new_value": values.get("multi", dash.no_update),
+                        "conditions": {"tab": selected_tab, "selector": selector},
                     }
-                    for item in ["SOURCE", "ENSEMBLE", "REAL"]
+                    for selector, values in output.items()
                 ],
             ),
             update_relevant_components(
                 id_list=filter_ids,
                 update_info=[
                     {
-                        "new_value": output[item].get("values", dash.no_update),
-                        "conditions": {"tab": selected_tab, "selector": item},
+                        "new_value": values.get("values", dash.no_update),
+                        "conditions": {"tab": selected_tab, "selector": selector},
                     }
-                    for item in ["SOURCE", "ENSEMBLE", "REAL"]
+                    for selector, values in output.items()
                 ],
             ),
             update_relevant_components(
@@ -410,25 +418,74 @@ def selections_controllers(
             )
 
         # if input_selector == "select"
-        elements = prev_selection if prev_selection is not None else reals
         return update_relevant_components(
             id_list=wrapper_ids,
             update_info=[
                 {
-                    "new_value": wcc.Select(
+                    "new_value": wcc.SelectWithLabel(
                         id={
                             "id": get_uuid("filters"),
                             "tab": selected_tab,
                             "component_type": page_value[0],
                         },
                         options=[{"label": i, "value": i} for i in reals],
-                        value=elements,
-                        multi=True,
+                        value=prev_selection if prev_selection is not None else reals,
                         size=min(20, len(reals)),
-                        persistence=True,
-                        persistence_type="session",
                     ),
                     "conditions": {"tab": selected_tab},
                 }
             ],
         )
+
+    @app.callback(
+        Output(
+            {"id": get_uuid("selections"), "selector": ALL, "tab": "tornado"}, "options"
+        ),
+        Output(
+            {"id": get_uuid("selections"), "selector": ALL, "tab": "tornado"}, "value"
+        ),
+        Output(
+            {"id": get_uuid("selections"), "selector": ALL, "tab": "tornado"},
+            "disabled",
+        ),
+        Input(
+            {"id": get_uuid("selections"), "selector": "mode", "tab": "tornado"},
+            "value",
+        ),
+        State({"id": get_uuid("selections"), "selector": ALL, "tab": "tornado"}, "id"),
+    )
+    def _update_tornado_selections_from_mode(mode: str, selector_ids: list) -> tuple:
+        settings = {}
+        if mode == "custom":
+            settings["Response left"] = settings["Response right"] = {
+                "options": [{"label": i, "value": i} for i in volumemodel.responses],
+                "disabled": False,
+            }
+        else:
+            volume_options = [
+                x for x in ["STOIIP", "GIIP"] if x in volumemodel.responses
+            ]
+            settings["Response left"] = {
+                "options": [{"label": "BULK", "value": "BULK"}],
+                "value": "BULK",
+                "disabled": True,
+            }
+            settings["Response right"] = {
+                "options": [{"label": i, "value": i} for i in volume_options],
+                "value": volume_options[0],
+                "disabled": len(volume_options) == 1,
+            }
+
+        return tuple(
+            update_relevant_components(
+                id_list=selector_ids,
+                update_info=[
+                    {
+                        "new_value": values.get(prop, dash.no_update),
+                        "conditions": {"selector": selector},
+                    }
+                    for selector, values in settings.items()
+                ],
+            )
+            for prop in ["options", "value", "disabled"]
+        )
